<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "並非所有的日曆都有完整的快取",
"Everything seems to be completely cached" => "所有東西應該都有快取了",
"No calendars found." => "沒有日曆",
"No events found." => "沒有活動",
"Wrong calendar" => "錯誤的日曆",
"You do not have the permissions to edit this event." => "您沒有權限編輯這個活動。",
"The file contained either no events or all events are already saved in your calendar." => "檔案中沒有包含任何活動，或是所有的活動都已經儲存至您的日曆中了。",
"Import failed" => "匯入失敗",
"New Timezone:" => "新時區：",
"Timezone changed" => "時區已變更",
"Invalid request" => "無效請求",
"Calendar" => "日曆",
"Deletion failed" => "移除失敗",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "群組",
"can edit" => "可編輯",
"can share" => "可分享",
"ddd" => "ddd",
"ddd M/d" => "M/d ddd",
"dddd M/d" => "M/d dddd",
"MMMM yyyy" => "yyyy MMMM",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "MMM d, dddd, yyyy",
"Sunday" => "週日",
"Monday" => "週一",
"Tuesday" => "週二",
"Wednesday" => "週三",
"Thursday" => "週四",
"Friday" => "週五",
"Saturday" => "週六",
"Sun." => "日",
"Mon." => "一",
"Tue." => "二",
"Wed." => "三",
"Thu." => "四",
"Fri." => "五",
"Sat." => "六",
"January" => "一月",
"February" => "二月",
"March" => "三月",
"April" => "四月",
"May" => "五月",
"June" => "六月",
"July" => "七月",
"August" => "八月",
"September" => "九月",
"October" => "十月",
"November" => "十一月",
"December" => "十二月",
"Jan." => "一月",
"Feb." => "二月",
"Mar." => "三月",
"Apr." => "四月",
"May." => "五月",
"Jun." => "六月",
"Jul." => "七月",
"Aug." => "八月",
"Sep." => "九月",
"Oct." => "十月",
"Nov." => "十一月",
"Dec." => "十二月",
"All day" => "整天",
"New Calendar" => "新日曆",
"Missing or invalid fields" => "欄位沒有填寫或無效的資料",
"Title" => "標題",
"From Date" => "自日期",
"From Time" => "自時間",
"To Date" => "至日期",
"To Time" => "至時間",
"The event ends before it starts" => "活動的結束在開始之前",
"There was a database fail" => "資料庫錯誤",
"Birthday" => "生日",
"Business" => "商業",
"Call" => "聯絡",
"Clients" => "客戶",
"Deliverer" => "遞送者",
"Holidays" => "節日",
"Ideas" => "主意",
"Journey" => "旅行",
"Jubilee" => "周年慶",
"Meeting" => "會議",
"Other" => "其他",
"Personal" => "個人",
"Projects" => "計畫",
"Questions" => "問題",
"Work" => "工作",
"by" => "由",
"unnamed" => "未命名",
"You do not have the permissions to update this calendar." => "您沒有權限更新這個日曆。",
"You do not have the permissions to delete this calendar." => "您沒有權限刪除這個日曆。",
"You do not have the permissions to add to this calendar." => "您沒有權限在這個日曆建立活動。",
"You do not have the permissions to add events to this calendar." => "您沒有權限在這個日曆建立活動。",
"You cannot add non-public events to a shared calendar." => "您無法在已分享的日暦中新增非公開事件",
"You do not have the permissions to delete this event." => "您沒有權限刪除這個活動。",
"Busy" => "忙碌",
"Show full event" => "顯示完整事件",
"Show only busy" => "只顯示忙碌事件",
"Hide event" => "隱藏事件",
"Does not repeat" => "不重覆",
"Daily" => "每日",
"Weekly" => "每週",
"Every Weekday" => "每週一至週五",
"Bi-Weekly" => "每隔一週",
"Monthly" => "每月",
"Yearly" => "每年",
"never" => "永不",
"by occurrences" => "由次數",
"by date" => "由日期",
"by monthday" => "依月份日期",
"by weekday" => "由平日",
"events week of month" => "月份中活動週",
"first" => "第一",
"second" => "第二",
"third" => "第三",
"fourth" => "第四",
"fifth" => "第五",
"last" => "最後",
"by events date" => "由活動日期",
"by yearday(s)" => "依年份日期",
"by weeknumber(s)" => "由週數",
"by day and month" => "由日與月",
"Contact birthdays" => "聯絡人生日",
"Date" => "日期",
"Cal." => "行事曆",
"Day" => "日",
"Week" => "週",
"Month" => "月",
"Today" => "今天",
"CalDav Link" => "CalDav 連結",
"Timezone" => "時區",
"Update timezone automatically" => "自動更新時區",
"Time format" => "時間格式",
"24h" => "24小時制",
"12h" => "12小時制",
"Start week on" => "一週起始於",
"Cache" => "快取",
"Clear cache for repeating events" => "清除重覆發生活動的快取",
"Primary CalDAV address" => "主要的 CalDAV 位址",
"iOS/OS X CalDAV address" => "iOS/OS X CalDAV 位址",
"Share Calendar" => "分享日曆",
"Download" => "下載",
"Edit" => "編輯",
"Delete" => "刪除",
"New calendar" => "新日曆",
"Edit calendar" => "編輯日曆",
"Edit event" => "編輯事件",
"Save event" => "儲存事件",
"Delete event" => "刪除事件",
"Eventinfo" => "活動資訊",
"Repeating" => "重覆中",
"Alarm" => "鬧鐘",
"Attendees" => "出席者",
"Share" => "分享",
"Title of the Event" => "活動標題",
"from" => "從",
"to" => "至",
"All Day Event" => "全天活動",
"Advanced options" => "進階選項",
"Location" => "位置",
"Categories (separate by comma)" => "分類 (用逗號分隔)",
"Edit categories" => "編輯分類",
"Description" => "描述",
"Export event" => "匯出事件",
"Repeat" => "重覆",
"Advanced" => "進階",
"Select weekdays" => "選擇平日",
"Select days" => "選擇日",
"and the events day of year." => "以及年中的活動日",
"and the events day of month." => "以及月中的活動日",
"Select months" => "選擇月",
"Select weeks" => "選擇週",
"and the events week of year." => "以及年中的活動週",
"Interval" => "間隔",
"End" => "結束",
"occurrences" => "次數",
"Visibility to people shared with" => "與朋友共享使用",
"create a new calendar" => "建立新日曆",
"Import a calendar file" => "匯入日曆檔案",
"Please choose a calendar" => "請選擇一個日曆",
"Name of new calendar" => "新日曆名稱",
"Take an available name!" => "請取一個尚未被使用的名稱！",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "已存在一個具有相同名稱的日曆。如果您依然要繼續，這些日曆將會合併成一個。",
"Remove all events from the selected calendar" => "刪除選取的日曆中所有的活動",
"Import" => "匯入",
"Close Dialog" => "關閉對話框",
"Create a new event" => "建立新活動",
"Create event" => "建立事件",
"Share with user or group" => "與用戶或群組分享",
"Unshare" => "取消共享",
"Not shared with anyone" => "未分享給任何人",
"Send Email" => "傳送信件",
"Shared via calendar" => "透過日曆分享",
"Not shared with anyone via calendar" => "未透過日暦分享給任何人",
"View an event" => "檢視活動",
"Category" => "分類",
"No categories selected" => "沒有選擇分類",
"%s of %s" => "%s 的 %s",
"Access Class" => "存取群組",
"From" => "自",
"at" => "於",
"To" => "至"
);
